#include <avr/io.h>
#include <util/delay.h>
#include <dogm_lcd.h>

void spi_init (void) 							// SPI initialisieren
{
	DDRB |= (1<<LCD_SS) | (1<<LCD_MOSI);		// setze MOSI,PB0 (SS) als Ausgang
	DDRB |= (1<<LCD_RS) | (1<<LCD_SCK);		// setze SCK, RS als Ausgang
	DDRB &= ~(1<<LCD_MISO);					// setze MISO als Eingang
	PORTB |= (1<<LCD_SCK) | (1<<LCD_SS);		// SCK und PB0 high (ist mit SS am Slave verbunden)
	SPCR = (1<<SPE) | (1<<MSTR) | (1<<SPR0);	// Aktivierung des SPI, Master, Taktrate fck/16
}

void SPI_transmit (unsigned char data) 	// SPI Datenbertragung
{
	PORTB &= ~(1<<LCD_SS);				// SS am Slave Low --> Beginn der bertragung
	SPDR = data;						// Schreiben der Daten
	while (!(SPSR & (1<<SPIF)));
	PORTB |= (1<<LCD_SS);				// SS High --> Ende der bertragung
	_delay_ms(2);
}


void display_init (void)				// Display initialisieren
{
	_delay_ms(50);						// Warten bis Display sicher versorgt
	PORTB &= ~(1<<LCD_RS);				// LCD_RS Low setzen (Befehlsregister)
	
	SPI_transmit(0b00111001);			// Datenlnge, Zeilenzahl, 3 getrennte Zeilen, Instruction-table 1 		
										// (Function Set)
	
	SPI_transmit(0b00111001);			// Befehl wiederholen														
										// (Function Set)
	
	SPI_transmit(0b00010101);			// Bias, Fixed-on-high (3-Line) and fixed on low (other apps)
										// (Bias Set)
	
	SPI_transmit(0b01111101);			// Kontrast setzen
										// (Contrast Set(low Byte))
	
	SPI_transmit(0b01010110);			// Icon-Display on/off, Booster on/off, Contrast set (internal-follower-mode)
										// (Power/ICON control/Contrast Set (high Byte))
	
	SPI_transmit(0b01101110);			// Spannungsfolger und Verstrkung setzen
										// (Follower Control)
	
	SPI_transmit(0b00001111);			// Display on/Cursour on/Blink on
										// (Display ON/OFF)
}


void LCD_print_char(unsigned char data)
{
	PORTB |= (1<<LCD_RS);				// RS auf high setzen (Datenregister)
	SPI_transmit(data);
	while (!(SPSR & (1<<SPIF)));
}

void LCD_print_string (unsigned char *buffer)
{
	while (*buffer != 0)
	{
		LCD_print_char(*buffer);
		buffer++;
	}
}